<?php

namespace Drp\SimpleCms\Generators\Crud\Simple;

use Drp\SimpleCms\Generators\Crud\Core;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class Template
{
    public static function create(string $name): void
    {
        $adminViews = base_path('resources/views/admin/' . Str::plural(strtolower($name)));

        if (!File::exists($adminViews)) {
            File::makeDirectory($adminViews, 0755, true, true);
        }

        foreach (self::getPaths($name) as $templatePath => $file) {
            Core::create($templatePath, $file, $name);
        }
    }

    public static function getPaths(string $name): array
    {
        $name = ucfirst($name);
        $configPrefix = 'simple_cms.generator.templates.simple';

        return [
            Storage::path(config("$configPrefix.factory"))
                => base_path("database/factories/{$name}Factory.php"),
            Storage::path(config("$configPrefix.migration"))
                => base_path(
                    'database/migrations/'
                    . date('Y_m_d_His')
                    . '_create_'
                    . Str::plural(strtolower($name))
                    . '_table.php'
                ),
            Storage::path(config("$configPrefix.seeder")) => base_path("database/seeds/{$name}Seeder.php"),
            Storage::path(config("$configPrefix.model")) => base_path("app/Models/{$name}.php"),
            Storage::path(config("$configPrefix.admin_controller"))
                => base_path('app/Http/Controllers/Admin/' . Str::plural($name) . "Controller.php"),
            Storage::path(config("$configPrefix.requests.store"))
                => base_path("app/Http/Requests/Store{$name}.php"),
            Storage::path(config("$configPrefix.requests.update"))
                => base_path("app/Http/Requests/Update{$name}.php"),
            Storage::path(config("$configPrefix.tests"))
                => base_path('tests/Feature/Admin/' . Str::plural($name) . "Test.php"),
            Storage::path(config("$configPrefix.admin_views") . '/form.blade.txt')
                => base_path('resources/views/admin/' . Str::plural(strtolower($name))) . '/form.blade.php',
            Storage::path(config("$configPrefix.admin_views") . '/index.blade.txt')
                => base_path('resources/views/admin/' . Str::plural(strtolower($name))) . '/index.blade.php',
            Storage::path(config("$configPrefix.policies")) => base_path("app/Policies/{$name}Policy.php"),
        ];
    }
}
