<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Contracts\ValidatesOnPublish;
use Drp\SimpleCms\Validator;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Http\RedirectResponse;
use Illuminate\Routing\Controller;

class PublishController extends Controller
{
    use AuthorizesRequests;

    /**
     * @var \Drp\SimpleCms\ContentFactory;
     */
    private $contentFactory;

    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }

    public function __invoke(Validator $validator, string $contentType, int $versionId): RedirectResponse
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        $this->authorize('publish', $content);

        if ($content instanceof ValidatesOnPublish && !$content->isPublished()) {
            $validator->validateContent($content);
        }


        $content->updatePublishStatus();
        flash()->success(
            trans('simpleCms::content.' . ($content->isPublished() ? 'published' : 'unpublished'))
        );

        return redirect()->back();
    }
}
